@@ -22,8 +22,6 @@ from .class_imbalance_data_check import ClassImbalanceDataCheck
 from .multicollinearity_data_check import MulticollinearityDataCheck
 from .sparsity_data_check import SparsityDataCheck
 from .uniqueness_data_check import UniquenessDataCheck
-from .datetime_nan_data_check import DateTimeNaNDataCheck
-from .natural_language_nan_data_check import NaturalLanguageNaNDataCheck
 from .target_distribution_data_check import TargetDistributionDataCheck
 from .datetime_format_data_check import DateTimeFormatDataCheck
 from .ts_parameters_data_check import TimeSeriesParametersDataCheck
