@@ -109,6 +109,12 @@ class DataCheckMessageCode(Enum):
     DATETIME_HAS_UNEVEN_INTERVALS = "datetime_has_uneven_intervals"
     """Message code for when the datetime values have uneven intervals."""
 
+    DATETIME_HAS_REDUNDANT_ROW = "datetime_has_redundant_row"
+    """Message code for when datetime information has more than one row per datetime"""
+
+    DATETIME_IS_MISSING_VALUES = "datetime_is_missing_values"
+    """Message code for when datetime feature has values missing between the start and end dates"""
+
     DATETIME_IS_NOT_MONOTONIC = "datetime_is_not_monotonic"
     """Message code for when the datetime values are not monotonically increasing."""
 
