@@ -3,11 +3,12 @@ import woodwork as ww
 
 from evalml.data_checks import (
     DataCheck,
-    DataCheckAction,
     DataCheckActionCode,
+    DataCheckActionOption,
     DataCheckError,
     DataCheckMessageCode,
     DataCheckWarning,
+    DCAOParameterType,
 )
 from evalml.objectives import get_objective
 from evalml.problem_types import (
@@ -75,96 +76,122 @@ class InvalidTargetDataCheck(DataCheck):
 
             >>> X = pd.DataFrame({"col": [1, 2, 3, 1]})
             >>> y = pd.Series(["cat_1", "cat_2", "cat_1", "cat_2"])
-            >>> target_check = InvalidTargetDataCheck('regression', 'R2')
-            >>> assert target_check.validate(X, y) == {
-            ...     'warnings': [],
-            ...     'errors': [{'message': 'Target is unsupported Unknown type. Valid Woodwork logical types include: integer, double, boolean, integer_nullable, boolean_nullable, age_nullable',
-            ...                 'data_check_name': 'InvalidTargetDataCheck',
-            ...                 'level': 'error',
-            ...                 'details': {'columns': None, 'rows': None, 'unsupported_type': 'unknown'},
-            ...                 'code': 'TARGET_UNSUPPORTED_TYPE'},
-            ...                {'message': 'Target data type should be numeric for regression type problems.',
-            ...                 'data_check_name': 'InvalidTargetDataCheck',
-            ...                 'level': 'error',
-            ...                 'details': {'columns': None, 'rows': None},
-            ...                 'code': 'TARGET_UNSUPPORTED_TYPE'}],
-            ...     'actions': []}
+            >>> target_check = InvalidTargetDataCheck("regression", "R2")
+            >>> assert target_check.validate(X, y) == [
+            ...     {
+            ...         "message": "Target is unsupported Unknown type. Valid Woodwork logical types include: integer, double, boolean, integer_nullable, boolean_nullable, age_nullable",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "error",
+            ...         "details": {"columns": None, "rows": None, "unsupported_type": "unknown"},
+            ...         "code": "TARGET_UNSUPPORTED_TYPE",
+            ...         "action_options": []
+            ...     },
+            ...     {
+            ...         "message": "Target data type should be numeric for regression type problems.",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "error",
+            ...         "details": {"columns": None, "rows": None},
+            ...         "code": "TARGET_UNSUPPORTED_TYPE",
+            ...         "action_options": []
+            ...     }
+            ... ]
 
             The target cannot have null values.
 
             >>> y = pd.Series([None, pd.NA, pd.NaT, None])
-            >>> assert target_check.validate(X, y) == {
-            ...     'warnings': [],
-            ...     'errors': [{'message': 'Target is either empty or fully null.',
-            ...                 'data_check_name': 'InvalidTargetDataCheck',
-            ...                 'level': 'error',
-            ...                 'details': {'columns': None, 'rows': None},
-            ...                 'code': 'TARGET_IS_EMPTY_OR_FULLY_NULL'}],
-            ...     'actions': []}
+            >>> assert target_check.validate(X, y) == [
+            ...     {
+            ...         "message": "Target is either empty or fully null.",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "error",
+            ...         "details": {"columns": None, "rows": None},
+            ...         "code": "TARGET_IS_EMPTY_OR_FULLY_NULL",
+            ...         "action_options": []
+            ...     }
+            ... ]
             ...
             ...
             >>> y = pd.Series([1, None, 3, None])
-            >>> assert target_check.validate(None, y) == {
-            ...     'warnings': [],
-            ...     'errors': [{'message': '2 row(s) (50.0%) of target values are null',
-            ...                 'data_check_name': 'InvalidTargetDataCheck',
-            ...                 'level': 'error',
-            ...                 'details': {'columns': None,
-            ...                             'rows': None,
-            ...                             'num_null_rows': 2,
-            ...                             'pct_null_rows': 50.0},
-            ...                 'code': 'TARGET_HAS_NULL'}],
-            ...     'actions': [{'code': 'IMPUTE_COL',
-            ...                  'data_check_name': 'InvalidTargetDataCheck',
-            ...                  'metadata': {'columns': None,
-            ...                               'rows': None,
-            ...                               'is_target': True,
-            ...                               'impute_strategy': 'mean'}}]}
+            >>> assert target_check.validate(None, y) == [
+            ...     {
+            ...         "message": "2 row(s) (50.0%) of target values are null",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "error",
+            ...         "details": {
+            ...             "columns": None,
+            ...             "rows": None,
+            ...             "num_null_rows": 2,
+            ...             "pct_null_rows": 50.0
+            ...         },
+            ...         "code": "TARGET_HAS_NULL",
+            ...         "action_options": [
+            ...            {
+            ...                 "code": "IMPUTE_COL",
+            ...                 "data_check_name": "InvalidTargetDataCheck",
+            ...                 "parameters": {
+            ...                     "impute_strategy": {
+            ...                         "parameter_type": "global",
+            ...                         "type": "category",
+            ...                         "categories": ["mean", "most_frequent"],
+            ...                         "default_value": "mean"
+            ...                     }
+            ...                 },
+            ...                 "metadata": {"columns": None, "rows": None, "is_target": True},
+            ...             }
+            ...         ],
+            ...     }
+            ... ]
 
             If the target values don't match the problem type passed, an error will be raised.
             In this instance, only two values exist in the target column, but multiclass has been passed as the problem type.
 
             >>> X = pd.DataFrame([i for i in range(50)])
             >>> y = pd.Series([i%2 for i in range(50)])
-            >>> target_check = InvalidTargetDataCheck('multiclass', 'Log Loss Multiclass')
-            >>> assert target_check.validate(X, y) == {
-            ...     'warnings': [],
-            ...     'errors': [{'message': 'Target has two or less classes, which is too few for multiclass problems.  Consider changing to binary.',
-            ...                 'data_check_name': 'InvalidTargetDataCheck',
-            ...                 'level': 'error',
-            ...                 'details': {'columns': None, 'rows': None, 'num_classes': 2},
-            ...                 'code': 'TARGET_MULTICLASS_NOT_ENOUGH_CLASSES'}],
-            ...     'actions': []}
+            >>> target_check = InvalidTargetDataCheck("multiclass", "Log Loss Multiclass")
+            >>> assert target_check.validate(X, y) == [
+            ...     {
+            ...         "message": "Target has two or less classes, which is too few for multiclass problems.  Consider changing to binary.",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "error",
+            ...         "details": {"columns": None, "rows": None, "num_classes": 2},
+            ...         "code": "TARGET_MULTICLASS_NOT_ENOUGH_CLASSES",
+            ...         "action_options": []
+            ...     }
+            ... ]
 
-            If the length of X and y differ, a warning will be raised. A warning will also be raised for indices that don't match.
+            If the length of X and y differ, a warning will be raised. A warning will also be raised for indices that don"t match.
 
-            >>> target_check = InvalidTargetDataCheck('regression', 'R2')
+            >>> target_check = InvalidTargetDataCheck("regression", "R2")
             >>> X = pd.DataFrame([i for i in range(5)])
             >>> y = pd.Series([1, 2, 4, 3], index=[1, 2, 4, 3])
-            >>> assert target_check.validate(X, y) == {
-            ...     'warnings': [{'message': 'Input target and features have different lengths',
-            ...                   'data_check_name': 'InvalidTargetDataCheck',
-            ...                   'level': 'warning',
-            ...                   'details': {'columns': None,
-            ...                               'rows': None,
-            ...                               'features_length': 5,
-            ...                               'target_length': 4},
-            ...                   'code': 'MISMATCHED_LENGTHS'},
-            ...                  {'message': 'Input target and features have mismatched indices. Details will include the first 10 mismatched indices.',
-            ...                   'data_check_name': 'InvalidTargetDataCheck',
-            ...                   'level': 'warning',
-            ...                   'details': {'columns': None,
-            ...                               'rows': None,
-            ...                               'indices_not_in_features': [],
-            ...                               'indices_not_in_target': [0]},
-            ...                   'code': 'MISMATCHED_INDICES'}],
-            ...     'errors': [],
-            ...     'actions': []}
+            >>> assert target_check.validate(X, y) == [
+            ...     {
+            ...         "message": "Input target and features have different lengths",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "warning",
+            ...         "details": {"columns": None, "rows": None, "features_length": 5, "target_length": 4},
+            ...         "code": "MISMATCHED_LENGTHS",
+            ...         "action_options": []
+            ...     },
+            ...     {
+            ...         "message": "Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
+            ...         "data_check_name": "InvalidTargetDataCheck",
+            ...         "level": "warning",
+            ...         "details": {
+            ...             "columns": None,
+            ...             "rows": None,
+            ...             "indices_not_in_features": [],
+            ...             "indices_not_in_target": [0]
+            ...         },
+            ...         "code": "MISMATCHED_INDICES",
+            ...         "action_options": []
+            ...     }
+            ... ]
         """
-        results = {"warnings": [], "errors": [], "actions": []}
+        messages = []
 
         if y is None:
-            results["errors"].append(
+            messages.append(
                 DataCheckError(
                     message="Target is None",
                     data_check_name=self.name,
@@ -172,29 +199,26 @@ class InvalidTargetDataCheck(DataCheck):
                     details={},
                 ).to_dict()
             )
-            return results
+            return messages
 
         y = infer_feature_types(y)
-        results = self._check_target_has_nan(y, results)
-        if any(
-            error["code"] == "TARGET_IS_EMPTY_OR_FULLY_NULL"
-            for error in results["errors"]
-        ):
+        messages = self._check_target_has_nan(y, messages)
+        if any(error["code"] == "TARGET_IS_EMPTY_OR_FULLY_NULL" for error in messages):
             # If our target is empty or fully null, no need to check for other invalid targets, return immediately.
-            return results
-        results = self._check_target_is_unsupported_type(y, results)
-        results = self._check_regression_target(y, results)
-        results = self._check_classification_target(y, results)
-        results = self._check_for_non_positive_target(y, results)
-        results = self._check_target_and_features_compatible(X, y, results)
-        return results
+            return messages
+        messages = self._check_target_is_unsupported_type(y, messages)
+        messages = self._check_regression_target(y, messages)
+        messages = self._check_classification_target(y, messages)
+        messages = self._check_for_non_positive_target(y, messages)
+        messages = self._check_target_and_features_compatible(X, y, messages)
+        return messages
 
-    def _check_target_is_unsupported_type(self, y, results):
+    def _check_target_is_unsupported_type(self, y, messages):
         is_supported_type = y.ww.logical_type.type_string in numeric_and_boolean_ww + [
             ww.logical_types.Categorical.type_string,
         ]
         if not is_supported_type:
-            DataCheck._add_message(
+            messages.append(
                 DataCheckError(
                     message="Target is unsupported {} type. Valid Woodwork logical types include: {}".format(
                         type(y.ww.logical_type),
@@ -203,28 +227,26 @@ class InvalidTargetDataCheck(DataCheck):
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE,
                     details={"unsupported_type": y.ww.logical_type.type_string},
-                ),
-                results,
+                ).to_dict()
             )
-        return results
+        return messages
 
-    def _check_target_has_nan(self, y, results):
+    def _check_target_has_nan(self, y, messages):
         null_rows = y.isnull()
         if null_rows.all():
-            DataCheck._add_message(
+            messages.append(
                 DataCheckError(
                     message="Target is either empty or fully null.",
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
                     details={},
-                ),
-                results,
+                ).to_dict()
             )
-            return results
+            return messages
         elif null_rows.any():
             num_null_rows = null_rows.sum()
             pct_null_rows = null_rows.mean() * 100
-            DataCheck._add_message(
+            messages.append(
                 DataCheckError(
                     message="{} row(s) ({}%) of target values are null".format(
                         num_null_rows, pct_null_rows
@@ -235,25 +257,31 @@ class InvalidTargetDataCheck(DataCheck):
                         "num_null_rows": num_null_rows,
                         "pct_null_rows": pct_null_rows,
                     },
-                ),
-                results,
-            )
-            impute_strategy = (
-                "mean" if is_regression(self.problem_type) else "most_frequent"
-            )
-            results["actions"].append(
-                DataCheckAction(
-                    DataCheckActionCode.IMPUTE_COL,
-                    data_check_name=self.name,
-                    metadata={
-                        "is_target": True,
-                        "impute_strategy": impute_strategy,
-                    },
+                    action_options=[
+                        DataCheckActionOption(
+                            DataCheckActionCode.IMPUTE_COL,
+                            data_check_name=self.name,
+                            parameters={
+                                "impute_strategy": {
+                                    "parameter_type": DCAOParameterType.GLOBAL,
+                                    "type": "category",
+                                    "categories": ["mean", "most_frequent"]
+                                    if is_regression(self.problem_type)
+                                    else ["most_frequent"],
+                                    "default_value": "mean"
+                                    if is_regression(self.problem_type)
+                                    else "most_frequent",
+                                }
+                            },
+                            metadata={"is_target": True},
+                        )
+                    ],
                 ).to_dict()
             )
-        return results
 
-    def _check_target_and_features_compatible(self, X, y, results):
+        return messages
+
+    def _check_target_and_features_compatible(self, X, y, messages):
         if X is not None:
             X = infer_feature_types(X)
             X_index = list(X.index)
@@ -261,7 +289,7 @@ class InvalidTargetDataCheck(DataCheck):
             X_length = len(X_index)
             y_length = len(y_index)
             if X_length != y_length:
-                DataCheck._add_message(
+                messages.append(
                     DataCheckWarning(
                         message="Input target and features have different lengths",
                         data_check_name=self.name,
@@ -270,25 +298,23 @@ class InvalidTargetDataCheck(DataCheck):
                             "features_length": X_length,
                             "target_length": y_length,
                         },
-                    ),
-                    results,
+                    ).to_dict()
                 )
 
             if X_index != y_index:
                 if set(X_index) == set(y_index):
-                    DataCheck._add_message(
+                    messages.append(
                         DataCheckWarning(
                             message="Input target and features have mismatched indices order.",
                             data_check_name=self.name,
                             message_code=DataCheckMessageCode.MISMATCHED_INDICES_ORDER,
                             details={},
-                        ),
-                        results,
+                        ).to_dict()
                     )
                 else:
                     index_diff_not_in_X = list(set(y_index) - set(X_index))[:10]
                     index_diff_not_in_y = list(set(X_index) - set(y_index))[:10]
-                    DataCheck._add_message(
+                    messages.append(
                         DataCheckWarning(
                             message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
                             data_check_name=self.name,
@@ -297,12 +323,11 @@ class InvalidTargetDataCheck(DataCheck):
                                 "indices_not_in_features": index_diff_not_in_X,
                                 "indices_not_in_target": index_diff_not_in_y,
                             },
-                        ),
-                        results,
+                        ).to_dict()
                     )
-        return results
+        return messages
 
-    def _check_for_non_positive_target(self, y, results):
+    def _check_for_non_positive_target(self, y, messages):
         any_neg = (
             not (y > 0).all()
             if y.ww.logical_type.type_string
@@ -316,31 +341,29 @@ class InvalidTargetDataCheck(DataCheck):
             details = {
                 "Count of offending values": sum(val <= 0 for val in y.values.flatten())
             }
-            DataCheck._add_message(
+            messages.append(
                 DataCheckError(
                     message=f"Target has non-positive values which is not supported for {self.objective.name}",
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
                     details=details,
-                ),
-                results,
+                ).to_dict()
             )
-        return results
+        return messages
 
-    def _check_regression_target(self, y, results):
+    def _check_regression_target(self, y, messages):
         if is_regression(self.problem_type) and "numeric" not in y.ww.semantic_tags:
-            DataCheck._add_message(
+            messages.append(
                 DataCheckError(
                     message="Target data type should be numeric for regression type problems.",
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE,
                     details={},
-                ),
-                results,
+                ).to_dict()
             )
-        return results
+        return messages
 
-    def _check_classification_target(self, y, results):
+    def _check_classification_target(self, y, messages):
         value_counts = y.value_counts()
         unique_values = value_counts.index.tolist()
 
@@ -353,14 +376,13 @@ class InvalidTargetDataCheck(DataCheck):
                         : min(self.n_unique, len(unique_values))
                     ]
                 }
-            DataCheck._add_message(
+            messages.append(
                 DataCheckError(
                     message="Binary class targets require exactly two unique values.",
                     data_check_name=self.name,
                     message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
                     details=details,
-                ),
-                results,
+                ).to_dict()
             )
         elif is_multiclass(self.problem_type):
             if value_counts.min() <= 1:
@@ -370,37 +392,34 @@ class InvalidTargetDataCheck(DataCheck):
                         least_populated.index.tolist()
                     )
                 }
-                DataCheck._add_message(
+                messages.append(
                     DataCheckError(
                         message="Target does not have at least two instances per class which is required for multiclass classification",
                         data_check_name=self.name,
                         message_code=DataCheckMessageCode.TARGET_MULTICLASS_NOT_TWO_EXAMPLES_PER_CLASS,
                         details=details,
-                    ),
-                    results,
+                    ).to_dict()
                 )
             if len(unique_values) <= 2:
                 details = {"num_classes": len(unique_values)}
-                DataCheck._add_message(
+                messages.append(
                     DataCheckError(
                         message="Target has two or less classes, which is too few for multiclass problems.  Consider changing to binary.",
                         data_check_name=self.name,
                         message_code=DataCheckMessageCode.TARGET_MULTICLASS_NOT_ENOUGH_CLASSES,
                         details=details,
-                    ),
-                    results,
+                    ).to_dict()
                 )
 
             num_class_to_num_value_ratio = len(unique_values) / len(y)
             if num_class_to_num_value_ratio >= self.multiclass_continuous_threshold:
                 details = {"class_to_value_ratio": num_class_to_num_value_ratio}
-                DataCheck._add_message(
+                messages.append(
                     DataCheckWarning(
                         message="Target has a large number of unique values, could be regression type problem.",
                         data_check_name=self.name,
                         message_code=DataCheckMessageCode.TARGET_MULTICLASS_HIGH_UNIQUE_CLASS,
                         details=details,
-                    ),
-                    results,
+                    ).to_dict()
                 )
-        return results
+        return messages
