@@ -1,3 +1,4 @@
+"""Metaclass that overrides creating a new component by wrapping methods with validators and setters."""
 from functools import wraps
 
 from evalml.exceptions import ComponentNotYetFittedError
@@ -5,12 +6,22 @@ from evalml.utils.base_meta import BaseMeta
 
 
 class ComponentBaseMeta(BaseMeta):
-    """Metaclass that overrides creating a new component by wrapping methods with validators and setters"""
+    """Metaclass that overrides creating a new component by wrapping methods with validators and setters."""
 
     @classmethod
     def check_for_fit(cls, method):
         """`check_for_fit` wraps a method that validates if `self._is_fitted` is `True`.
+
         It raises an exception if `False` and calls and returns the wrapped method if `True`.
+
+        Args:
+            method (callable): Method to wrap.
+
+        Returns:
+            The wrapped method.
+
+        Raises:
+            ComponentNotYetFittedError: If component is not yet fitted.
         """
 
         @wraps(method)
