@@ -1,3 +1,4 @@
+"""XGBoost Regressor."""
 from skopt.space import Integer, Real
 
 from evalml.model_family import ModelFamily
@@ -12,7 +13,7 @@ from evalml.utils.gen_utils import (
 class XGBoostRegressor(Estimator):
     """XGBoost Regressor.
 
-    Arguments:
+    Args:
         eta (float): Boosting learning rate. Defaults to 0.1.
         max_depth (int): Maximum tree depth for base learners. Defaults to 6.
         min_child_weight (float): Minimum sum of instance weight (hessian) needed in a child. Defaults to 1.0
@@ -85,6 +86,15 @@ class XGBoostRegressor(Estimator):
         }
 
     def fit(self, X, y=None):
+        """Fits XGBoost regressor component to data.
+
+        Args:
+            X (pd.DataFrame): The input training data of shape [n_samples, n_features].
+            y (pd.Series, optional): The target training data of length [n_samples].
+
+        Returns:
+            self
+        """
         X, y = super()._manage_woodwork(X, y)
         X.ww.set_types(self._convert_bool_to_int(X))
         self.input_feature_names = list(X.columns)
@@ -93,6 +103,14 @@ class XGBoostRegressor(Estimator):
         return self
 
     def predict(self, X):
+        """Make predictions using fitted XGBoost regressor.
+
+        Args:
+            X (pd.DataFrame): Data of shape [n_samples, n_features].
+
+        Returns:
+            pd.Series: Predicted values.
+        """
         X, _ = super()._manage_woodwork(X)
         X.ww.set_types(self._convert_bool_to_int(X))
         X = _rename_column_names_to_numeric(X, flatten_tuples=False)
@@ -100,4 +118,5 @@ class XGBoostRegressor(Estimator):
 
     @property
     def feature_importance(self):
+        """Feature importance of fitted XGBoost regressor."""
         return self._component_obj.feature_importances_
