@@ -3,11 +3,7 @@ import pandas as pd
 from sklearn.discriminant_analysis import LinearDiscriminantAnalysis as SkLDA
 
 from evalml.pipelines.components.transformers import Transformer
-from evalml.utils import (
-    _retain_custom_types_and_initalize_woodwork,
-    infer_feature_types,
-    is_all_numeric,
-)
+from evalml.utils import infer_feature_types, is_all_numeric
 
 
 class LinearDiscriminantAnalysis(Transformer):
@@ -82,7 +78,8 @@ class LinearDiscriminantAnalysis(Transformer):
             index=X_ww.index,
             columns=[f"component_{i}" for i in range(X_t.shape[1])],
         )
-        return _retain_custom_types_and_initalize_woodwork(X_ww, X_t)
+        X_t.ww.init()
+        return X_t
 
     def fit_transform(self, X, y=None):
         """Fit and transform data using the LDA component.
@@ -108,4 +105,5 @@ class LinearDiscriminantAnalysis(Transformer):
             index=X_ww.index,
             columns=[f"component_{i}" for i in range(X_t.shape[1])],
         )
-        return _retain_custom_types_and_initalize_woodwork(X_ww, X_t)
+        X_t.ww.init()
+        return X_t
