@@ -4,14 +4,13 @@ import numpy as np
 import pandas as pd
 import pytest
 from pandas.testing import assert_frame_equal
-from pytest import importorskip
 
 from evalml.model_family import ModelFamily
 from evalml.pipelines import LightGBMClassifier
 from evalml.problem_types import ProblemTypes
 from evalml.utils import SEED_BOUNDS
 
-lgbm = importorskip("lightgbm", reason="Skipping test because lightgbm not installed")
+pytestmark = pytest.mark.noncore_dependency
 
 
 def test_model_family():
@@ -44,7 +43,8 @@ def test_lightgbm_classifier_random_seed_bounds_seed(X_y_binary):
     clf.fit(X, y)
 
 
-def test_fit_predict_binary(X_y_binary):
+def test_fit_predict_binary(X_y_binary, lgbm):
+
     X, y = X_y_binary
 
     sk_clf = lgbm.sklearn.LGBMClassifier(random_state=0)
@@ -61,7 +61,8 @@ def test_fit_predict_binary(X_y_binary):
     np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.values, decimal=5)
 
 
-def test_fit_predict_multi(X_y_multi):
+def test_fit_predict_multi(X_y_multi, lgbm):
+
     X, y = X_y_multi
 
     clf = lgbm.sklearn.LGBMClassifier(random_state=0)
@@ -78,7 +79,8 @@ def test_fit_predict_multi(X_y_multi):
     np.testing.assert_almost_equal(y_pred_proba_sk, y_pred_proba.values, decimal=5)
 
 
-def test_feature_importance(X_y_binary):
+def test_feature_importance(X_y_binary, lgbm):
+
     X, y = X_y_binary
 
     clf = LightGBMClassifier(n_jobs=1)
@@ -92,7 +94,8 @@ def test_feature_importance(X_y_binary):
     np.testing.assert_almost_equal(sk_feature_importance, feature_importance, decimal=5)
 
 
-def test_fit_string_features(X_y_binary):
+def test_fit_string_features(X_y_binary, lgbm):
+
     X, y = X_y_binary
     X = pd.DataFrame(X)
     X["string_col"] = "abc"
@@ -262,7 +265,8 @@ def test_binary_label_encoding(mock_predict, X_y_binary):
     clf.predict(X)
 
 
-def test_binary_rf(X_y_binary):
+def test_binary_rf(X_y_binary, lgbm):
+
     X, y = X_y_binary
 
     with pytest.raises(lgbm.basic.LightGBMError, match="bagging_fraction"):
