@@ -81,6 +81,21 @@ def test_invalid_inputs():
         encoder.fit(X)
 
 
+def test_ohe_is_no_op_for_not_categorical_features():
+
+    ohe = OneHotEncoder(handle_missing="error")
+    X = pd.DataFrame(
+        {
+            "col_1": [1.2, 3.2, None, 4.7],
+            "col_2": [4.5, 8.9, 11.2, 23.4],
+            "col_3": [True, False, True, True],
+        }
+    )
+    X.ww.init(logical_types={"col_1": "Double", "col_2": "Integer", "col_3": "Boolean"})
+    X_t = ohe.fit_transform(X)
+    pd.testing.assert_frame_equal(X_t, X)
+
+
 def test_null_values_in_dataframe():
     X = pd.DataFrame(
         {
@@ -134,7 +149,7 @@ def test_null_values_in_dataframe():
     assert X_t.shape == (5, 6)
 
     # Test handle_missing='error' throws an error
-    encoder = OneHotEncoder(handle_missing="error")
+    encoder_error = OneHotEncoder(handle_missing="error")
 
     X = pd.DataFrame(
         {
@@ -144,9 +159,9 @@ def test_null_values_in_dataframe():
             "col_4": [2, 0, 1, 3, 0, 1, 2],
         }
     )
-
+    X.ww.init(logical_types={"col_1": "categorical"})
     with pytest.raises(ValueError, match="Input contains NaN"):
-        encoder.fit(X)
+        encoder_error.fit(X)
 
     # Test NaN values in transformed data
     X = pd.DataFrame(
@@ -165,8 +180,10 @@ def test_null_values_in_dataframe():
             "col_3": ["a", "a", "a", "a", "a"],
         }
     )
+    X_missing.ww.init(logical_types={"col_2": "categorical"})
+    encoder_error = OneHotEncoder(handle_missing="error")
     with pytest.raises(ValueError, match="Input contains NaN"):
-        encoder.transform(X_missing)
+        encoder_error.fit(X_missing)
 
 
 def test_drop_first():
